(* Guestfs Browser.
 * Copyright (C) 2010 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *)

module D = Libvirt.Domain
module G = Guestfs

type domain = {
  dom_id : int;
  dom_name : string;
  dom_state : D.state;
}

and inspection_data = {
  insp_all_filesystems : (string * string) list;
  insp_oses : inspection_os list;
}

and inspection_os = {
  insp_root : string;
  insp_arch : string;
  insp_distro : string;
  insp_drive_mappings : (string * string) list;
  insp_filesystems : string array;
  insp_hostname : string;
  insp_major_version : int;
  insp_minor_version : int;
  insp_mountpoints : (string * string) list;
  insp_package_format : string;
  insp_package_management : string;
  insp_product_name : string;
  insp_product_variant : string;
  insp_type : string;
  insp_windows_current_control_set : string option;
  insp_windows_systemroot : string option;
  insp_winreg_DEFAULT : string option;
  insp_winreg_SAM : string option;
  insp_winreg_SECURITY : string option;
  insp_winreg_SOFTWARE : string option;
  insp_winreg_SYSTEM : string option;
}

and source = OS of inspection_os | Volume of string

and direntry = {
  dent_name : string;
  dent_stat : G.stat;
  dent_link : string;
}

and download_dir_tarball_format = Tar | TGZ | TXZ
